Struct ra_ap_project_model::CargoConfig
source · pub struct CargoConfig {Show 14 fields
pub features: CargoFeatures,
pub target: Option<String>,
pub sysroot: Option<RustLibSource>,
pub sysroot_query_metadata: bool,
pub sysroot_src: Option<AbsPathBuf>,
pub rustc_source: Option<RustLibSource>,
pub cfg_overrides: CfgOverrides,
pub wrap_rustc_in_build_scripts: bool,
pub run_build_script_command: Option<Vec<String>>,
pub extra_args: Vec<String>,
pub extra_env: FxHashMap<String, String>,
pub invocation_strategy: InvocationStrategy,
pub invocation_location: InvocationLocation,
pub target_dir: Option<PathBuf>,
}Fields
features: CargoFeaturesList of features to activate.
target: Option<String>rustc target
sysroot: Option<RustLibSource>Sysroot loading behavior
sysroot_query_metadata: boolWhether to invoke cargo metadata on the sysroot crate.
sysroot_src: Option<AbsPathBuf>rustc_source: Option<RustLibSource>rustc private crate source
cfg_overrides: CfgOverrideswrap_rustc_in_build_scripts: boolInvoke cargo check through the RUSTC_WRAPPER.
run_build_script_command: Option<Vec<String>>The command to run instead of cargo check for building build scripts.
extra_args: Vec<String>Extra args to pass to the cargo command.
extra_env: FxHashMap<String, String>Extra env vars to set when invoking the cargo command
invocation_strategy: InvocationStrategyinvocation_location: InvocationLocationtarget_dir: Option<PathBuf>Optional path to use instead of target when building